[**Commencer**](./commencer.md) > **Utilisation** > **Ligne de commande** _(actuel)_

---

### Utiliser PDFMathTranslate via la ligne de commande

#### Utilisation de base

Après l'installation, veuillez entrer cette commande pour traduire votre PDF.

```bash
pdf2zh_next document.pdf
```

> [!NOTE]
> 
> Si votre chemin d'accès contient des espaces, veuillez l'entourer de guillemets.
> 
> ```bash
> pdf2zh_next "path with spaces/document.pdf"
> ```

Après l'exécution de la traduction, les fichiers sont générés dans le **répertoire de travail actuel**.

> [!TIP]
> **Où se trouve mon "Répertoire de travail actuel" ?**
> Avant d'entrer une commande dans le terminal, vous pourriez voir un chemin affiché dans votre terminal :
> 
> ```powershell
> PS C:\Users\XXX>
> ```
> 
> Ce répertoire est le "*Répertoire de travail actuel*."
> 
> S'il n'y a pas de chemin, essayez d'exécuter cette commande dans le terminal :
> 
> ```bash
> pwd
> ```
> 
> Après avoir exécuté cette commande, un chemin sera affiché. Ce chemin est le "**Répertoire de travail actuel**". Les fichiers traduits apparaîtront ici.

---

#### Options avancées

Pour des explications détaillées sur les paramètres supplémentaires de la ligne de commande, veuillez consulter [Options avancées](./../advanced/advanced.md).

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>